# themispy

<p align="center">
    <img widht="300" height="460" src="https://cdn.discordapp.com/attachments/970738555695542283/1008823964061139066/justice_serpent-01.jpg">
</p>


<p align="center">
    <sub align="center">Serpente da Justiça</sub>
</p>

--------------------------------

[![Python 3.8](https://img.shields.io/badge/python-3.8-blue.svg)](https://www.python.org/downloads/release/python-3813/)
![PyPI](https://img.shields.io/pypi/v/themispy)

Seja bem-vindo(a) ao componente themispy! Este componente foi construído durante o desenvolvimento do projeto Themis para auxiliar na componentização de estruturas do projeto relacionadas ao framework [Scrapy](https://scrapy.org/) e sua extensão para utilização em conjunto com a [Azure](https://github.com/Azure/azure-sdk-for-python).

O componente foi projetado para ser o mais simples possível e sua estrutura foi desenvolvida seguindo os padrões do próprio framework, a fim de se manter um padrão de uso e documentação, facilitando dessa maneira o desenvolvimento.

Você pode acessar a documentação [aqui](https://themispy.readthedocs.io/pt_BR/latest/index.html).
